"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactTestingLibrary = require("react-testing-library");

var _styledComponents = require("styled-components");

var _ = _interopRequireDefault(require(".."));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

it('accepts an `as` prop to change the rendered DOM element', function () {
  var _render = (0, _reactTestingLibrary.render)(_react.default.createElement(_.default, {
    as: "span"
  }, "Hello World")),
      container = _render.container;

  expect(container.firstChild).toMatchSnapshot();
});
it('accepts a `css` prop', function () {
  var _render2 = (0, _reactTestingLibrary.render)(_react.default.createElement(_.default, {
    css: {
      color: 'red'
    }
  }, "Hello World")),
      container = _render2.container;

  expect(container.firstChild).toMatchSnapshot();
});
it('accepts a `theme` prop', function () {
  var theme = {
    colors: {
      blue: '#07f'
    }
  };

  var _render3 = (0, _reactTestingLibrary.render)(_react.default.createElement(_.default, {
    theme: theme,
    css: {
      color: '$colors.blue'
    }
  }, "Hello World")),
      container = _render3.container;

  expect(container.firstChild).toMatchSnapshot();
});
describe('`css` prop', function () {
  it('supports nesting', function () {
    var _render4 = (0, _reactTestingLibrary.render)(_react.default.createElement(_.default, {
      css: {
        boxSizing: 'border-box',
        '.foo': {
          color: 'red'
        },
        '& *, & *::before, & *::after': {
          boxSizing: 'inherit'
        }
      }
    }, "Hello World")),
        container = _render4.container;

    expect(container.firstChild).toMatchSnapshot();
  });
  it('supports pseudo-classes and pseudo-elements', function () {
    var _render5 = (0, _reactTestingLibrary.render)(_react.default.createElement(_.default, {
      css: {
        color: 'red',
        '&:hover': {
          color: 'blue'
        },
        '&::before': {
          content: '"🌎"'
        }
      }
    }, "Hello World")),
        container = _render5.container;

    expect(container.firstChild).toMatchSnapshot();
  });
  it('evaluates theme keys prefixed with "$"', function () {
    var theme = {
      spacing: ['0', '4px', '8px', '16px', '24px', '32px'],
      colors: {
        blue: '#07f',
        gray: '#ccc'
      }
    };

    var _render6 = (0, _reactTestingLibrary.render)(_react.default.createElement(_styledComponents.ThemeProvider, {
      theme: theme
    }, _react.default.createElement(_.default, {
      css: {
        display: 'inline-block',
        padding: '$spacing.1 $spacing.2',
        margin: '-$spacing.1 auto',
        color: '$colors.blue',
        backgroundColor: '$foo'
      }
    }, "Hello World"))),
        container = _render6.container;

    expect(container.firstChild).toMatchSnapshot();
  });
  it('supports responsive values', function () {
    var theme = {
      spacing: ['0', '4px', '8px', '16px', '24px', '32px'],
      fontSizes: ['12px', '14px', '16px', '20px', '24px'],
      breakpoints: ['576px', '768px', '992px']
    };

    var _render7 = (0, _reactTestingLibrary.render)(_react.default.createElement(_styledComponents.ThemeProvider, {
      theme: theme
    }, _react.default.createElement(_.default, {
      css: {
        width: ['100%', '50%'],
        margin: [],
        padding: ['$spacing.0', '$spacing.1', '$spacing.2', '$spacing.3'],
        fontSize: [null, '$fontSizes.0', null, '$fontSizes.1', '$fontSizes.2']
      }
    }, "Hello World"))),
        container = _render7.container;

    expect(container.firstChild).toMatchSnapshot();
  });
  it('provides default breakpoints', function () {
    var _render8 = (0, _reactTestingLibrary.render)(_react.default.createElement(_.default, {
      css: {
        width: ['100%', '90%', '80%', '70%', '60%']
      }
    }, "Hello World")),
        container = _render8.container;

    expect(container.firstChild).toMatchSnapshot();
  });
});